@@ -1,5 +1,6 @@
 import os
 import time
+import requests
 import LibHanger.Library.uwLogger as Logger
 from os import path
 from bs4 import BeautifulSoup
@@ -27,6 +28,9 @@ class baseWebBrowserController:
 
         # Webドライバーインスタンス格納用変数初期化
         self.wDriver:WebDriver = None
+        
+        # BeautifulSoupインスタンス格納用変数初期化
+        self.bSoup:BeautifulSoup = None
 
         # コールバック関数
         self.cbCreateSearchResultDictionaryByWebDriver = baseWebBrowserController.createSearchResultDictionaryByWebDriver
@@ -108,9 +112,13 @@ class baseWebBrowserController:
         
         # URLログ出力
         Logger.logging.info('TargetUrl]' + url)
-        
-        # ページ内容取得
-        self.wDriver.get(url)
+
+        # ページ内容取得        
+        if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
+            self.wDriver.get(url)
+        elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
+            response = requests.get(url)
+            self.bSoup = BeautifulSoup(response.content, 'lxml')
 
     @Logger.loggerDecorator('Normal-Delay')
     def Delay(self):
@@ -182,8 +190,7 @@ class baseWebBrowserController:
                 # 待機
                 self.Delay()
                 # スクレイピング
-                soup:BeautifulSoup = self.scrapingWithBeautifulSoup()
-                return self.cbCreateSearchResultDictionaryByBeutifulSoup(self, soup, dfItemInfo, dictItemInfoRowCount)
+                return self.cbCreateSearchResultDictionaryByBeutifulSoup(self, self.bSoup, dfItemInfo, dictItemInfoRowCount)
     
     @Logger.loggerDecorator('Create SearchResultDictionary By WebDriver')
     def createSearchResultDictionaryByWebDriver(self, element, dfItemInfo:DataFrame, dictItemInfoRowCount:int) -> dict:
@@ -211,7 +218,7 @@ class baseWebBrowserController:
         pass
 
     @Logger.loggerDecorator('Create SearchResultDictionary By BeutifulSoup') 
-    def createSearchResultDictionaryByBeutifulSoup(self, soup, dfItemInfo:DataFrame, dictItemInfoRowCount:int) -> dict:
+    def createSearchResultDictionaryByBeutifulSoup(self, soup:BeautifulSoup, dfRaceInfo:DataFrame, dictRaceInfoRowCount:int) -> dict:
         
         """
         ByBeutifulSoupを使用してスレイピング結果からDictionaryを生成する(デリゲート用関数)
