@@ -13,6 +13,27 @@ class browserContainer:
     ブラウザコンテナクラス
     """
 
+    class beautifulSoup(baseWebBrowserController):
+    
+        """
+        beautifulSoup用コンテナ
+        """
+    
+        def __init__(self, _config: scrapingConfig):
+            
+            """
+            コンストラクタ
+            
+            Parameters 
+            ----------
+            _config : scrapingConfig
+                共通設定クラス
+
+            """
+            
+            # 基底側コンストラクタ呼び出し
+            super().__init__(_config)
+    
     class chrome(baseWebBrowserController):
         
         """
