@@ -2,6 +2,7 @@ import LibHanger.Library.uwLogger as Logger
 from Scrapinger.Library.baseWebDriverController import baseWebDriverController
 from Scrapinger.Library.browserController import browserContainer
 from Scrapinger.Library.scrapingConfig import scrapingConfig
+from Scrapinger.Library.scrapingerException import scrapingerException
 
 class webDriverController(baseWebDriverController):
     
@@ -33,6 +34,26 @@ class webDriverController(baseWebDriverController):
         
         # ブラウザーコントロールインスタンス初期化
         self.browserCtl = None
+
+    @Logger.loggerDecorator('Setting Scrape')    
+    def settingScrape(self):
+        if self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.beutifulSoup.value:
+            self.getBeautifulSoupInstance()
+        elif self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.selenium.value:
+            self.getWebDriverInstance()
+    
+    @Logger.loggerDecorator('Get BeautifulSoupInstance')    
+    def getBeautifulSoupInstance(self):
+        
+        """
+        BeautifulSoupインスタンスを取得する
+        """ 
+        
+        if self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.beutifulSoup.value:
+            self.browserCtl = self.browserContainerInstance.beautifulSoup(self.config)
+        else:
+            # 例外とする
+            raise scrapingerException.scrapingTypeErrorException
     
     @Logger.loggerDecorator('Get WebDriverInstance')
     def getWebDriverInstance(self):
@@ -49,6 +70,9 @@ class webDriverController(baseWebDriverController):
         elif self.config.BrowserType == scrapingConfig.settingValueStruct.BrowserType.firefox.value:
             self.browserCtl = self.browserContainerInstance.firefox(self.config)
             browserName = scrapingConfig.settingValueStruct.BrowserType.firefox.name
+        else:
+            # 例外とする
+            raise scrapingerException.scrapingTypeErrorException
         
         # 取得したWebDriverをログ出力
         Logger.logging.info('BrowserType:' + str(self.config.BrowserType))
